@@ -16,17 +16,16 @@ class GitService(BaseService):
         self.repo_path = os.path.curdir
         self.printer = PrettyPrint()
 
-    def init(self) -> bool:
+    def init(self) -> str:
         """
         Responsible for running git init
         :return:
         """
-        try:
-            pygit2.init_repository(self.repo_path)
-            return True
-        except Exception as e:
-            self.printer.error(str(e))
-            return False
+        # Check if git is already initialized
+        if does_file_exist(f"{self.repo_path}/.git"):
+            return "git already initialized"
+        pygit2.init_repository(self.repo_path)
+        return "git initialized successfully"
 
     def status(self) -> Any:
         """
